@@ -21,12 +21,14 @@
  */
 #include "common.h"
 #include "string.h"
+#include <stdlib.h>
+#include <limits.h>
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <errno.h>
 
 static void usage(void) {
-  printf("Usage: newplaylist -i <fileid/trackid> -n <playlistname>\n");
+  printf("Usage: newplaylist -i <fileid/trackid> -n <playlistname> -s <storage_id> -p <parent_id>\n");
   exit(0);
 }
 
@@ -40,10 +42,12 @@ int main (int argc, char **argv) {
   uint32_t *tmp = NULL;
   char *playlistname = NULL;
   char *rest;
+  uint32_t storageid = 0;
+  uint32_t parentid = 0;
  
   fprintf(stdout, "libmtp version: " LIBMTP_VERSION_STRING "\n\n");
 
-  while ( (opt = getopt(argc, argv, "hn:i:")) != -1 ) {
+  while ( (opt = getopt(argc, argv, "hn:i:s:p:")) != -1 ) {
     switch (opt) {
     case 'h':
       usage();
@@ -59,6 +63,12 @@ int main (int argc, char **argv) {
     case 'n':
       playlistname = strdup(optarg);
       break;
+    case 's':
+      storageid = (uint32_t) strtoul(optarg, NULL, 0);
+	  break;
+    case 'p':
+      parentid = (uint32_t) strtoul(optarg, NULL, 0);
+	  break;
     default:
       usage();
     }
@@ -88,7 +98,9 @@ int main (int argc, char **argv) {
   playlist->name = playlistname;
   playlist->no_tracks = idcount;
   playlist->tracks = ids;
-  int ret = LIBMTP_Create_New_Playlist(device,playlist,0);
+  playlist->parent_id = parentid;
+  playlist->storage_id = storageid;
+  int ret = LIBMTP_Create_New_Playlist(device,playlist);
   if (ret != 0) {
     printf("Couldn't create playlist object\n");
     LIBMTP_Dump_Errorstack(device);
